@@ -1,22 +1,8 @@
 /*
- *  This file is part of the KDE Help Center
- *
- *  Copyright (C) 1999 Matthias Elter (me@kde.org)
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 1999 Matthias Elter <me@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "navigator.h"
 
@@ -74,7 +60,7 @@ Navigator::Navigator( View *view, QWidget *parent )
     mSearchEdit->setPlaceholderText( i18n("Search...") );
     mSearchEdit->setClearButtonEnabled(true);
     topLayout->addWidget( mSearchEdit );
-    connect(mSearchEdit, &KLineEdit::returnPressed, this, &Navigator::slotSearch);
+    connect(mSearchEdit, &KLineEdit::returnKeyPressed, this, &Navigator::slotSearch);
     connect(mSearchEdit, &KLineEdit::textChanged, this, &Navigator::checkSearchEdit);
 
     mTabWidget = new QTabWidget( this );
